@@ -1,3 +1,20 @@
+/*
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #include <config.h>
 #include <glib-object.h>
 #include <gtk/gtk.h>
@@ -5,16 +22,15 @@
 #include <libgnomeui/libgnomeui.h>
 #include <gconf/gconf-client.h>
 
+#undef GNOME_DISABLE_DEPRECATED
 #include <libgnomeui/gnome-hint.h>
 
 int main (int argc, char **argv) {
   GtkWidget *gnome_hint;
-  GnomeProgram *gnome_hint_program;
-  GConfClient* client;
 
   gchar *hintfile, *backimg, *logoimg;
 
-  gnome_hint_program = gnome_program_init("gnome-hint","0.1",LIBGNOMEUI_MODULE,
+  gnome_program_init("gnome-hint","0.1",LIBGNOMEUI_MODULE,
                                    argc, argv, NULL);
 
   if (argc !=4){
@@ -26,10 +42,6 @@ int main (int argc, char **argv) {
   backimg = g_strdup(argv[2]);
   logoimg = g_strdup(argv[3]);
 
-  client = gconf_client_get_default();
-/*  gconf_client_add_dir(client,"/apps/test-hint/",
-	GCONF_CLIENT_PRELOAD_NONE,NULL); */
-
   gnome_hint = gnome_hint_new (hintfile, "GNOME Test Hints",
 				backimg, logoimg, "/apps/test-hint/startup");
 
